Learn R Programming

bumblebee (version 0.1.0)

counts_hiv_transmission_pairs: Observed HIV transmission pairs

Description

Counts of directed HIV transmission pairs observed within and between intervention and control communities in the 30-community BCPP/Ya Tsie HIV prevention trial in Botswana (2013-2018). The Botswana -Ya Tsie trial was a pair-matched community randomized trial that evaluated the effect of a universal HIV test and treat intervention in reducing population-level incidence. For further details see references and: https://magosil86.github.io/bumblebee/.

Usage

counts_hiv_transmission_pairs

Arguments

Format

A data frame:

H1_group

Name of population group 1

H2_group

Name of population group 1

num_linked_pairs_observed

Number of observed directed transmission pairs between samples from population groups 1 and 2

References

Magosi LE, et al., Deep-sequence phylogenetics to quantify patterns of HIV transmission in the context of a universal testing and treatment trial <U+2013> BCPP/ Ya Tsie trial. To submit for publication, 2021.