# NOT RUN {
library(bumblebee)
library(dplyr)
# Estimate transmission flows within and between population groups accounting for variable
# sampling among population groups
# We shall use the data of HIV transmissions within and between intervention and control
# communities in the BCPP/Ya Tsie HIV prevention trial. To learn more about the data
# ?counts_hiv_transmission_pairs and ?sampling_frequency
# Load and view data
#
# The input data comprises counts of observed directed HIV transmission pairs within
# and between intervention and control communities in the BCPP/Ya Tsie trial,
# sampling information and the probability of linkage between individuals sampled
# from intervention and control communities (i.e. \code{p_hat})
#
# See ?estimate_p_hat() for details on estimating p_hat
results_estimate_p_hat <- estimated_hiv_transmission_flows[, c(1:10)]
results_estimate_p_hat
# Estimate theta_hat
results_estimate_theta_hat <- estimate_theta_hat(df_counts_and_p_hat = results_estimate_p_hat)
# View results
results_estimate_theta_hat
# }
Run the code above in your browser using DataLab